@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 22/02/2020
+   Date last update: 03/11/2022
  */
 
 #include "vmp_.h"
@@ -143,6 +143,7 @@ void vmp_init(pylib::Module module)
 
     //vmp/io.h
     module.def_with_stub("init",stub_init());
+    module.def_("is_debug_mode",vmp::is_debug_mode);
     module.def_("io_forced_unlock",vmp::io_forced_unlock);
     module.def_("debug",vmp::debug_s);
     module.def_("info",vmp::info_s);
@@ -158,6 +159,8 @@ void vmp_init(pylib::Module module)
     module.def_("input_file_s",vmp::input_file_s);
     module.def_("exit_ok",vmp::exit_ok);
     module.def_("exit_failure",vmp::exit_failure_s);
+    module.def_("copy_file",vmp::copy_file);
+    module.def_("move_file",vmp::move_file);
 
     //vmp/lib.h
     module.def_("system_wrap",vmp::system_wrap);
