@@ -131,7 +131,7 @@ void event_init_threadui(pylib::Module module)
     //event0/ui/threadui.h
     pylib::Class<PyThreadUI> threadui=module.class_with_constructor<PyThreadUI>("ThreadUI",ThreadUI_Constructor());
     threadui.def_with_stub("set_event",stub_ThreadUI_set_event());
-    threadui.def_("new_thread",&PyThreadUI::new_thread);
+    threadui.def_("new_thread",&PyThreadUI::new_thread,false);
     threadui.def_("start_thread",&PyThreadUI::start_thread);
     threadui.def_("id",&PyThreadUI::id);
 }
