@@ -155,6 +155,10 @@ class Plugin:
   def opt_err(self,opt):
     vmp.except_s("Option {0} bad value".format(opt))
 
+  ##Throw exception of the error required data
+  def opt_required(self,opt):
+    vmp.except_s("Option {0} required".format(opt))
+  
 ##Class for a module, contains the structures to manage a series of plugins
 class Module:
   ## A Constructor<BR>
