@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 05/03/2020
+   Date last update: 01/12/2022
  */
 
 #include "xml_.h"
@@ -41,6 +41,7 @@ class PyParser:public xml::DomParser
         xml::Tag *create_tag(vmp::str name);
         void destroy_impl();
     public:
+        pylib::PyCall defobj_;
         vmp::Table<vmp::str,pylib::PyCall *> typeobj_;
         PyParser();
         ~PyParser();
@@ -58,7 +59,7 @@ xml::Tag *PyParser::create_tag(vmp::str name)
 {
     pylib::PyCall *typeobj;
     if(!typeobj_.search(name,&typeobj))
-       return new xml::BaseTag();
+        typeobj=&defobj_;
     pylib::CArgs cargs(0);
     pylib::PyObj ret=typeobj->call(cargs);
     pylib::PyObj pytag=ret.get_attr("pytag");
@@ -71,6 +72,33 @@ void PyParser::destroy_impl()
     vmp::table_delete_alldata<vmp::str,pylib::PyCall *>(typeobj_);
 }
 
+struct PyParser_stub_Constructor:public pylib::Constructor<PyParser>
+{
+    PyParser *build_instance(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 1)
+        {
+            PyParser *parser=new PyParser();
+            try
+            {
+                 args.get_callable(0,parser->defobj_);
+            }
+            catch(vmp::invalid_argument &x)
+            {
+                delete parser;
+                args.arg_error();
+            }
+            catch(vmp::exception &x)
+            {
+                delete parser;
+                vmp::except_s(x.what());
+            }
+            return parser;
+        }
+        return 0;
+    }
+};
+
 struct stub_create_tag:public pylib::Generic_def
 {
     pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
@@ -146,7 +174,7 @@ struct stub_pyparser_get_root:public pylib::Member_def<PyParser>
             PyTag *pytag=(PyTag *)instance->get_root();
             if(pytag == 0)
                 return pylib::retnone();
-            return pylib::Converter<PyTag *>(pytag,false);
+            return pylib::Converter<pylib::Objref *>(pytag->pyobj_.ref(),false); 
         } 
         return 0;
     }
@@ -234,7 +262,7 @@ void xml_init_parser(pylib::Module module)
     module.def_with_stub("create_tag",stub_create_tag());
     
     //xml.h
-    pylib::Class<PyParser> pyparser=module.class_<PyParser>("Parser");
+    pylib::Class<PyParser> pyparser=module.class_with_constructor<PyParser>("Parser",PyParser_stub_Constructor());
     pyparser.def_with_stub("add_tag",stub_pyparser_add_tag());
     pyparser.def_with_stub("get_root",stub_pyparser_get_root());
     pyparser.def_with_stub("build",stub_pyparser_build());
