@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 06/04/2022
+   Date last update: 18/09/2022
  */
 
 #include "vmp.h"
@@ -40,6 +40,7 @@ class Json
 {
     private:
         struct json_object *ref_;/*!<json parser references*/
+        json::JsonObj *root_;/*!<json object root references*/
 
         //! Internal usage
         void reset();
@@ -59,40 +60,52 @@ class Json
 
         //! Takes the parser root object and references it to obj
         /*!
-            @param obj output object where the root object is referenced
+            @sa root_
+            @return json object root
         */
-        void root(json::JsonObj *obj);
+        json::JsonObj *root();
+
+        //! Set the root of the json parser in the input obj
+        /*!
+            @param obj output obj 
+            @sa root_
+            @return void or except in case of failure
+        */
+        void root_cpy(json::JsonObj *obj);
 
         //! Generates an empty parser
-        void json_new();
+        /*!
+            @return json object root
+        */
+        json::JsonObj *json_new();
 
         //! Generate a new parser from an input Json Object (Object type)
         /*!
             @param obj Json Object input
-            @return void or except in case of failure
+            @return json object root or except in case of failure
         */
-        void json_new_obj(json::JsonObj *obj);
+        json::JsonObj *json_new_obj(json::JsonObj *obj);
 
-        //! Duplicate parser to json output
+        //! Copy json parser to input
         /*!
-            @param json new duplicated parser created
-            @return void or except in case of failure
+            @param json json input; if json == 0 create empty parser
+            @return json object root
         */
-        void json_duplicate(json::Json *json);
+        json::JsonObj *json_duplicate(json::Json *json);
 
         //! Read a json string and create a json parser
         /*!
             @param str json string
-            @return void or except in case of failure
+            @return json object root or except in case of failure
         */
-        void parse_from_str(vmp::str str);
+        json::JsonObj *parse_from_str(vmp::str str);
 
         //! Read a json file and create a json parser
         /*!
             @param filepath path json file
-            @return void or except in case of failure
+            @return json object root or except in case of failure
         */
-        void parse_from_file(vmp::str filepath);
+        json::JsonObj *parse_from_file(vmp::str filepath);
 
         //! Returns the current json parser string to one line
         /*!
