@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 13/09/2021
+   Date last update: 18/09/2021
  */
 
 #include "json.h"
@@ -26,16 +26,20 @@ namespace vampiria { namespace json {
 Json::Json()
 {
     ref_=json_object_new_object();
+    root_=new JsonObj();
+    root_->ref_=ref_;
 }
         
 Json::~Json()
 {
     reset();
+    delete root_;
 }
 
 void Json::reset()
 {
     json_object_put(ref_);
+    root_->ref_=0;
 }
 
 void Json::check_null_input_obj(json::JsonObj *obj,vmp::str fname)
@@ -64,47 +68,54 @@ void Json::parse(vmp::str str)
     }
     json_tokener_reset(tok);
     ref_=jobj;
+    root_->ref_=ref_;
 }
 
-void Json::root(json::JsonObj *obj)
+json::JsonObj *Json::root()
 {
-    check_null_input_obj(obj,"root");
-    obj->ref_=ref_;   
+    return root_;   
 }
 
-void Json::json_new()
+void Json::root_cpy(json::JsonObj *obj)
+{
+    check_null_input_obj(obj,"root_cpy");
+    obj->ref_=ref_;
+}
+
+json::JsonObj *Json::json_new()
 {
     reset();
     ref_=json_object_new_object();
+    root_->ref_=ref_;
+    return root_;
 }
 
-void Json::json_new_obj(json::JsonObj *obj)
+json::JsonObj *Json::json_new_obj(json::JsonObj *obj)
 {
     check_null_input_obj(obj,"json_new_obj");
     if(!(obj->isobject()))
         vmp::except_s("json::Json::json_new_obj() data input invalid json object");
     json_new();
-    json::JsonObj oroot,kobj;
-    root(&oroot);
+    json::JsonObj kobj;
     vmp::vector<vmp::str> keys=obj->keys();
     for(vmp_index i=0;i<keys.size();i++)
     {
          obj->get_object(keys[i],&kobj);
-         oroot.add_object_ex(keys[i],&kobj);
+         root_->add_object_ex(keys[i],&kobj);
     }
+    return root_;
 }
 
-void Json::json_duplicate(json::Json *json)
+json::JsonObj *Json::json_duplicate(json::Json *json)
 {
-    json::JsonObj oroot;
     if(json == 0)
-        vmp::except_s("json::Json::json_duplicate() null input json parser");
-    root(&oroot);
-    json->json_new_obj(&oroot);
-        
+        json_new();
+    else
+        json_new_obj(json->root());    
+    return root_;
 }
 
-void Json::parse_from_str(vmp::str str)
+json::JsonObj *Json::parse_from_str(vmp::str str)
 {
     try
     {
@@ -114,9 +125,10 @@ void Json::parse_from_str(vmp::str str)
     {
         vmp::except("json::Json::parse_from_str() error '%s'",x.what());
     }
+    return root_;
 }
 
-void Json::parse_from_file(vmp::str filepath)
+json::JsonObj *Json::parse_from_file(vmp::str filepath)
 {
     try
     {
@@ -127,6 +139,7 @@ void Json::parse_from_file(vmp::str filepath)
     {
         vmp::except("json::Json::parse_from_file('%s') error '%s'",filepath.c_str(),x.what());
     }
+    return root_;
 }
 
 vmp::str Json::json_str()
@@ -152,6 +165,7 @@ void Json::json_to_file(vmp::str filepath)
     }
     
 }
+
 JsonObj::JsonObj()
 {
     ref_=0;
