@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 17/03/2020
+   Date last update: 04/11/2022
  */
 
 #include "modules.h"
@@ -271,8 +271,6 @@ modules::Module *ModUtils::module_from_parser(xml::Tag *rmodule,vmp::str id,vmp:
                 if(arg == 0)
                    break;
                 vmp::str text=arg->get_text();
-                if(text == "")
-                    arg->parser_error("Tag required text not empty");
                 if(arg->get_name() == "par")
                 {
                     if(par.size()+1 > itag->par_.size())
