@@ -127,7 +127,7 @@ class Packet
         //!Returns the data in string format associated with the field
         /*!
             @param field input field
-            @return assocaited data(except error)
+            @return associated data(except error)
         */
         virtual vmp::str get(vmp::str field);
 
