@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 25/11/2019
+   Date last update: 13/01/2023
  */
 
 #include "vmp.h"
@@ -59,11 +59,22 @@ void except_alloc()
     throw vmp::bad_alloc();
 }
 
+vmp::str value_errno()
+{
+    return vmp::strerror_wrap(errno);
+}
+
 void except_errno()
 {
     except_s(vmp::strerror_wrap(errno));
 }
 
+vmp::str value_errno_set(vmp_int err)
+{
+    errno=err;
+    return value_errno();
+}
+
 void except_errno_set(vmp_int err)
 {
     errno=err;
