@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 01/01/2020
+   Date last update: 27/12/2022
  */
 
 #include "vmp.h"
@@ -447,5 +447,13 @@ vmp::vector<vmp::str> str_regex(vmp::str str,vmp::str str_regex,vmp_bool icase)
     }
 }
 
+vmp_bool str_regex_matching(vmp::str str,vmp::str str_regex)
+{
+    vmp::vector<vmp::str> m=vmp::unicode::str_regex(str,str_regex);
+    if((m.size() == 1) && (m[0] == str))
+        return true;
+    return false;
+}
+
 }}}
 
