@@ -85,7 +85,9 @@ class DataTag(xml.Tag):
     
   def build(self):
     parent=self.get_parent()
-    parent.data.append(self.get_text())
+    text=self.get_text()
+    if text != '':
+      parent.data.append(text)
 
 class LabelTag(xml.Tag):
   def __init__(self):
@@ -119,7 +121,9 @@ class DSelectTag(xml.Tag):
     
   def build(self):
     parent=self.get_parent()
-    parent.dselect.append(self.get_text())
+    text=self.get_text()
+    if text != '':
+      parent.dselect.append(text)
     
 class OptionsTag(VarTag):
   def __init__(self):
@@ -160,7 +164,9 @@ class OptvalueTag(xml.Tag):
     
   def build(self):
     parent=self.get_parent()
-    parent.value.append(self.get_text())
+    text=self.get_text()
+    if text != '':
+      parent.value.append(text)
      
 class EntryAbsTag(VarTag):
   def __init__(self):
@@ -255,7 +261,7 @@ class ListEntryTag(EntryAbsTag):
     self.data=[]
     for v in value:
       self.check_data(v)
-      if value != '':
+      if v != '':
         self.data.append(v)
  
   def build_sub(self):
@@ -461,11 +467,26 @@ class PyCodeTag(xml.Tag):
     self.args=[]
     self.iargs=[]
     self.code=None
+    self.if_=None
+    self.ifnot_=None
    
   def build(self):
     self.code=self.get_attr("code")
     self.pyobj=pycode.PyObjTable[self.code]
     self.var=self.pytag.get_attr("var")
+    tmp=self.get_attrs_name()
+    if 'if_' in tmp:
+      value=pycode.new_data_type(self.pytag.get_attr('if_'))
+      if pycode.data_isvar(value):
+        self.if_=value
+      else:
+        self.parser_error("Attribute if_ must be an var data")
+    if 'ifnot_' in tmp:
+      value=pycode.new_data_type(self.pytag.get_attr('ifnot_'))
+      if pycode.data_isvar(value):
+        self.ifnot_=value
+      else:
+        self.parser_error("Attribute ifnot_ must be an var data")
     
   def build_mask(self,wmask):
     i=0
@@ -492,7 +513,18 @@ class PyCodeTag(xml.Tag):
        wmask.pycode.append(self)
        return
     self.parser_error("Invalid arguments for code \"{0}\" required {1}".format(self.code,self.pyobj.args))
-    
+     
+  def if_check(self,var):
+    if self.if_ != None:
+      v=pycode.data_dict_value(self.if_,var)
+      if len(v) == 0:
+        return False
+    if self.ifnot_ != None:
+      v=pycode.data_dict_value(self.ifnot_,var)
+      if not len(v) == 0:
+        return False
+    return True
+  
   def exec_code(self,var):
     i=0
     args=[]
@@ -569,9 +601,9 @@ class TreeTag(xml.Tag):
       if pycode.data_isvar(attr[1]):
         value=pycode.data_dict_value(attr[1],var)
         if len(value) > 0 and len(value[0]) > 0:
-          tag.add_attr(attr[0],value[0])  
+          tag.set_attr(attr[0],value[0])  
       else:
-        tag.add_attr(attr[0],pycode.data_value(attr[1]))
+        tag.set_attr(attr[0],pycode.data_value(attr[1]))
     
 
   def add_tag_text(self,ptag,text):
